"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var content_ref_1 = require("./content-ref");
var modal_backdrop_1 = require("./modal-backdrop");
var modal_window_1 = require("./modal-window");
var modal_ref_1 = require("./modal-ref");
var NgfModalStack = (function () {
    function NgfModalStack(_applicationRef, _injector, _componentFactoryResolver) {
        this._applicationRef = _applicationRef;
        this._injector = _injector;
        this._componentFactoryResolver = _componentFactoryResolver;
        this._backdropFactory = _componentFactoryResolver.resolveComponentFactory(modal_backdrop_1.NgfModalBackdrop);
        this._windowFactory = _componentFactoryResolver.resolveComponentFactory(modal_window_1.NgfModalWindow);
    }
    NgfModalStack.prototype.open = function (moduleCFR, contentInjector, content, options) {
        var containerSelector = options.container || 'body';
        var containerEl = document.querySelector(containerSelector);
        if (!containerEl) {
            throw new Error("The specified modal container \"" + containerSelector + "\" was not found in the DOM.");
        }
        var activeModal = new modal_ref_1.NgfActiveModal();
        var contentRef = this._getContentRef(moduleCFR, contentInjector, content, activeModal);
        var windowCmptRef;
        var backdropCmptRef;
        var ngfModalRef;
        if (options.backdrop !== false) {
            backdropCmptRef = this._backdropFactory.create(this._injector);
            this._applicationRef.attachView(backdropCmptRef.hostView);
            containerEl.appendChild(backdropCmptRef.location.nativeElement);
        }
        windowCmptRef = this._windowFactory.create(this._injector, contentRef.nodes);
        this._applicationRef.attachView(windowCmptRef.hostView);
        if (options.backdrop !== false) {
            backdropCmptRef.location.nativeElement.appendChild(windowCmptRef.location.nativeElement);
        }
        else {
            containerEl.appendChild(windowCmptRef.location.nativeElement);
        }
        ngfModalRef = new modal_ref_1.NgfModalRef(windowCmptRef, contentRef, backdropCmptRef);
        activeModal.close = function (result) { ngfModalRef.close(result); };
        activeModal.dismiss = function (reason) { ngfModalRef.dismiss(reason); };
        this._applyWindowOptions(windowCmptRef.instance, options);
        return ngfModalRef;
    };
    NgfModalStack.prototype._applyWindowOptions = function (windowInstance, options) {
        ['backdrop', 'keyboard', 'size', 'windowClass'].forEach(function (optionName) {
            if (options[optionName] !== undefined && options[optionName] !== null) {
                windowInstance[optionName] = options[optionName];
            }
        });
    };
    NgfModalStack.prototype._getContentRef = function (moduleCFR, contentInjector, content, context) {
        if (!content) {
            return new content_ref_1.ContentRef([]);
        }
        else if (content instanceof core_1.TemplateRef) {
            var viewRef = content.createEmbeddedView(context);
            this._applicationRef.attachView(viewRef);
            return new content_ref_1.ContentRef([viewRef.rootNodes], viewRef);
        }
        else if (typeof content === 'string') {
            return new content_ref_1.ContentRef([[document.createTextNode("" + content)]]);
        }
        else {
            var contentCmptFactory = moduleCFR.resolveComponentFactory(content);
            var modalContentInjector = core_1.ReflectiveInjector.resolveAndCreate([{ provide: modal_ref_1.NgfActiveModal, useValue: context }], contentInjector);
            var componentRef = contentCmptFactory.create(modalContentInjector);
            this._applicationRef.attachView(componentRef.hostView);
            return new content_ref_1.ContentRef([[componentRef.location.nativeElement]], componentRef.hostView, componentRef);
        }
    };
    return NgfModalStack;
}());
NgfModalStack.decorators = [
    { type: core_1.Injectable },
];
/** @nocollapse */
NgfModalStack.ctorParameters = function () { return [
    { type: core_1.ApplicationRef, },
    { type: core_1.Injector, },
    { type: core_1.ComponentFactoryResolver, },
]; };
exports.NgfModalStack = NgfModalStack;
//# sourceMappingURL=modal-stack.js.map