"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var modal_dismiss_reasons_1 = require("./modal-dismiss-reasons");
var NgfModalWindow = (function () {
    function NgfModalWindow(_elRef, _renderer) {
        this._elRef = _elRef;
        this._renderer = _renderer;
        this.backdrop = true;
        this.keyboard = true;
        this.dismissEvent = new core_1.EventEmitter();
    }
    NgfModalWindow.prototype.onResize = function (event) {
        if (!this.backdrop) {
            this.position();
        }
    };
    NgfModalWindow.prototype.position = function () {
        if (this.backdrop) {
            return;
        }
        var windowWidth = document.body.offsetWidth;
        var width = this._elRef.nativeElement.offsetWidth;
        var left = Math.round((windowWidth - width) / 2);
        this._renderer.setElementStyle(this._elRef.nativeElement, 'left', left + 'px');
    };
    NgfModalWindow.prototype.escKey = function ($event) {
        if (this.keyboard && !$event.defaultPrevented) {
            this.dismiss(modal_dismiss_reasons_1.ModalDismissReasons.ESC);
        }
    };
    NgfModalWindow.prototype.dismiss = function (reason) { this.dismissEvent.emit(reason); };
    NgfModalWindow.prototype.ngOnInit = function () {
        this._elWithFocus = document.activeElement;
        this._renderer.setElementClass(document.body, 'is-reveal-open', true);
        if (!this.backdrop) {
            this._renderer.setElementStyle(this._elRef.nativeElement, 'position', 'fixed');
            this.position();
        }
    };
    NgfModalWindow.prototype.ngAfterViewInit = function () {
        if (!this._elRef.nativeElement.contains(document.activeElement)) {
            this._renderer.invokeElementMethod(this._elRef.nativeElement, 'focus', []);
        }
    };
    NgfModalWindow.prototype.ngOnDestroy = function () {
        if (this._elWithFocus && document.body.contains(this._elWithFocus)) {
            this._renderer.invokeElementMethod(this._elWithFocus, 'focus', []);
        }
        else {
            this._renderer.invokeElementMethod(document.body, 'focus', []);
        }
        this._elWithFocus = null;
        this._renderer.setElementClass(document.body, 'is-reveal-open', false);
    };
    return NgfModalWindow;
}());
NgfModalWindow.decorators = [
    { type: core_1.Component, args: [{
                selector: 'Ngf-modal-window',
                host: {
                    '[class]': "\n      \"reveal\" + (windowClass ? \" \" + windowClass : \"\") + (size ? ' modal-' + size : '')\n    ",
                    'role': 'dialog',
                    'tabindex': '-1',
                    'style': 'display: block; visibility: visible;',
                    '(keyup.esc)': 'escKey($event)',
                    '[@modal]': ''
                },
                template: "\n    <ng-content></ng-content>\n  ",
                animations: [
                    core_1.trigger('modal', [
                        core_1.transition('void => *', [
                            core_1.style({ transform: 'scale3d(.3, .3, .3)' }),
                            core_1.animate(100)
                        ]),
                        core_1.transition('* => void', [
                            core_1.animate(100, core_1.style({ transform: 'scale3d(.0, .0, .0)' }))
                        ])
                    ])
                ]
            },] },
];
/** @nocollapse */
NgfModalWindow.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
    { type: core_1.Renderer, },
]; };
NgfModalWindow.propDecorators = {
    'backdrop': [{ type: core_1.Input },],
    'keyboard': [{ type: core_1.Input },],
    'size': [{ type: core_1.Input },],
    'windowClass': [{ type: core_1.Input },],
    'dismissEvent': [{ type: core_1.Output, args: ['dismiss',] },],
    'onResize': [{ type: core_1.HostListener, args: ['window:resize', ['$event'],] },],
};
exports.NgfModalWindow = NgfModalWindow;
//# sourceMappingURL=modal-window.js.map